@@ -62,7 +62,7 @@
 #define LAYERSHELLQTINTERFACE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef LAYERSHELLQTINTERFACE_NO_DEPRECATED
-#  define LAYERSHELLQTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6055b
+#  define LAYERSHELLQTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60600
 #endif
 #ifdef LAYERSHELLQTINTERFACE_NO_DEPRECATED_WARNINGS
 #  define LAYERSHELLQTINTERFACE_DEPRECATED_WARNINGS_SINCE 0
@@ -72,7 +72,7 @@
 #  ifdef LAYERSHELLQTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define LAYERSHELLQTINTERFACE_DEPRECATED_WARNINGS_SINCE LAYERSHELLQTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define LAYERSHELLQTINTERFACE_DEPRECATED_WARNINGS_SINCE 0x6055b
+#    define LAYERSHELLQTINTERFACE_DEPRECATED_WARNINGS_SINCE 0x60600
 #  endif
 #endif
 
